@@ -22,7 +22,7 @@
 #' @param stratify A list that specifies whether or not stratified sample splitting shall be performed. It is recommended to use the returned object of \code{\link{setup_stratify}} as this list. See the documentation of \code{\link{setup_stratify}} for details.
 #' @param significance_level Significance level for VEIN. Default is 0.05.
 #' @param min_variation Specifies a threshold for the minimum variation of the BCA/CATE predictions. If the variation of a BCA/CATE prediction falls below this threshold, random noise with distribution \eqn{N(0, var(Y)/20)} is added to it. Default is \code{1e-05}.
-#' @param parallel Logical. If \code{TRUE}, parallel computing will be used. On Unix systems, this will be done via forking (shared memory across threads). On non-Unix systems, this will be done through parallel socket clusters.
+#' @param parallel Logical. If \code{TRUE}, parallel computing will be used. Default is \code{FALSE}. On Unix systems, this will be done via forking (shared memory across threads). On non-Unix systems, this will be done through parallel socket clusters.
 #' @param num_cores Number of cores to be used in parallelization (if applicable). Default is the number of cores of the user's machine.
 #' @param seed Random seed. Default is \code{NULL} for no random seeding.
 #' @param store_learners Logical. If \code{TRUE}, all intermediate results of the learners will be stored. That is, for each learner and each split, all BCA and CATE predictions as well as all BLP, GATES, CLAN, and \eqn{\Lambda} estimates will be stored. Default is \code{FALSE}.
@@ -135,7 +135,7 @@ GenericML <- function(Z, D, Y,
                       stratify                 = setup_stratify(),
                       significance_level       = 0.05,
                       min_variation            = 1e-05,
-                      parallel                 = TrueIfUnix(),
+                      parallel                 = FALSE,
                       num_cores                = parallel::detectCores(),
                       seed                     = NULL,
                       store_learners           = FALSE,
